const std = @import("std");
const Module = @import("../module.zig");
const Self = @This();

module: Module,

pub fn init(allocator: std.mem.Allocator) Self {
    return .{
        .module = .{
            .allocator = allocator,
            .getJsonFn = getJson,
        },
    };
}

pub fn getJson(module: *const Module) !Module.JSON {
    const self: *const Self = @fieldParentPtr("module", module);

    const child = try std.ChildProcess.run(.{
        .argv = &[_][]const u8{ "amixer", "sget", "Master" },
        .allocator = self.module.allocator,
    });

    if (std.mem.indexOfScalar(u8, child.stdout, '[')) |volume_idx| {
        if (std.mem.indexOfScalarPos(u8, child.stdout, volume_idx, '%')) |percent_idx| {
            const volume = try std.fmt.parseInt(u8, child.stdout[volume_idx + 1 .. percent_idx], 10);
            return .{
                .full_text = try std.fmt.allocPrint(self.module.allocator, "{d: >2}%", .{volume}),
            };
        } else return .{ .full_text = "?" };
    } else return .{ .full_text = "?" };
}
